@@ -3,6 +3,7 @@
 from __future__ import annotations
 
 import base64
+import csv
 import glob
 import json
 import logging
@@ -11,6 +12,8 @@ import pickle
 import re
 import subprocess
 
+from calkit.models import ProjectStatus
+
 import requests
 
 try:
@@ -385,3 +388,32 @@ def get_size(path: str):
 def to_kebab_case(str) -> str:
     """Convert a string to kebab-case."""
     return re.sub(r"[-_,\.\ ]", "-", str.lower())
+
+
+def get_project_status_history(
+    wdir: str = None, as_pydantic=True
+) -> list[ProjectStatus] | list[dict]:
+    statuses = []
+    fpath = os.path.join(".calkit", "status.csv")
+    if wdir is not None:
+        fpath = os.path.join(wdir, fpath)
+    if os.path.isfile(fpath):
+        with open(fpath) as f:
+            reader = csv.reader(f)
+            next(reader, None)  # Skip header row
+            for line in reader:
+                ts, status, message = line
+                ts = datetime.fromisoformat(ts)
+                obj = ProjectStatus(
+                    timestamp=ts, status=status, message=message
+                )
+                if not as_pydantic:
+                    obj = obj.model_dump()
+                statuses.append(obj)
+    return statuses
+
+
+def get_latest_project_status(wdir: str = None) -> ProjectStatus | None:
+    statuses = get_project_status_history(wdir=wdir)
+    if statuses:
+        return statuses[-1]
